@@ -1,13 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-social" "20251124.950"
-  "An Org-social client."
+(define-package "org-social" "20260116.749"
+  "An Org-social client for Emacs."
   '((emacs   "30.1")
     (org     "9.0")
     (request "0.3.0")
     (seq     "2.20")
     (emojify "1.2"))
   :url "https://github.com/tanrax/org-social.el"
-  :commit "bdc0e7918abd9f9977e522d8a97acde2a1dd33f3"
-  :revdesc "bdc0e7918abd"
+  :commit "83015d1402c28cd1395b18a104dfbc4f1357a83c"
+  :revdesc "83015d1402c2"
   :authors '(("Andros Fenollosa" . "hi@andros.dev"))
   :maintainers '(("Andros Fenollosa" . "hi@andros.dev")))
